summaryrefslogtreecommitdiffstats
path: root/tdeui/kdockwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/kdockwidget.h')
-rw-r--r--tdeui/kdockwidget.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/tdeui/kdockwidget.h b/tdeui/kdockwidget.h
index 4f54e5f13..df06ed8f1 100644
--- a/tdeui/kdockwidget.h
+++ b/tdeui/kdockwidget.h
@@ -36,7 +36,7 @@
- KDockTabGroup - minor helper class
- KDockWidget - IMPORTANT CLASS: the one and only dockwidget class
- KDockManager - helper class
- - KDockMainWindow - IMPORTANT CLASS: a special KMainWindow that can have dockwidgets
+ - KDockMainWindow - IMPORTANT CLASS: a special TDEMainWindow that can have dockwidgets
- KDockArea - like KDockMainWindow but inherits just QWidget
IMPORTANT Note: This file compiles also in Qt-only mode by using the NO_KDE2 precompiler definition!
@@ -55,13 +55,13 @@
#include <tqtabwidget.h>
#ifndef NO_KDE2
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
#include <netwm_def.h>
#else
#include <tqmainwindow.h>
#include "exportdockclass.h"
-#include "dummykmainwindow.h"
+#include "dummytdemainwindow.h"
#endif
class KDockSplitter;
@@ -80,8 +80,8 @@ class TQHBoxLayout;
class TQPixmap;
#ifndef NO_KDE2
-class KToolBar;
-class KConfig;
+class TDEToolBar;
+class TDEConfig;
#else
class TQToolBar;
#endif
@@ -128,12 +128,12 @@ public:
/**
* Provides saving the current configuration. Must be overridden by an inheriting class.
*/
- virtual void saveConfig( KConfig* ){}
+ virtual void saveConfig( TDEConfig* ){}
/**
* Provides loading the current configuration. Must be overridden by an inheriting class
*/
- virtual void loadConfig( KConfig* ){}
+ virtual void loadConfig( TDEConfig* ){}
#endif
protected:
@@ -291,14 +291,14 @@ public:
*
* @param c the configuration safe
*/
- virtual void saveConfig( KConfig* c);
+ virtual void saveConfig( TDEConfig* c);
/**
* Loads the current button state from a KDE config container object.
*
* @param c the configuration safe
*/
- virtual void loadConfig( KConfig* c);
+ virtual void loadConfig( TDEConfig* c);
#endif
/*@since 3.2
@@ -906,7 +906,7 @@ private:
* that can be called within a KDockMainWindow or a KDockWidget .
*
* An important feature is the ability to read or save the current state of all things concerning to
* dockwidgets to KConfig .
*
* The dockmanager is also often used when a certain dockwidget or a child of such dockwidget must be found.
*
@@ -954,9 +954,9 @@ public:
* last but not least some necessary things for recovering the dockmainwindow state.
*
* @param c the KDE configuration saver
* @param group the name of the section in KConfig
*/
- void writeConfig( KConfig* c = 0L, TQString group = TQString::null );
+ void writeConfig( TDEConfig* c = 0L, TQString group = TQString::null );
/**
* Like writeConfig but reads the whole stuff in.
@@ -972,9 +972,9 @@ public:
* to work, each widget must have a unique name.
*
* @param c the KDE configuration saver
* @param group the name of the section in KConfig
*/
- void readConfig ( KConfig* c = 0L, TQString group = TQString::null );
+ void readConfig ( TDEConfig* c = 0L, TQString group = TQString::null );
#endif
/// @since 3.1
@@ -1033,7 +1033,7 @@ public:
KDockWidget* getDockWidgetFromName( const TQString& dockName );
/**
- * Enables opaque resizing. Opaque resizing defaults to KGlobalSettings::opaqueResize().
+ * Enables opaque resizing. Opaque resizing defaults to TDEGlobalSettings::opaqueResize().
* Call this method before you create any dock widgets!
*/
void setSplitterOpaqueResize(bool b=true);
@@ -1269,7 +1269,7 @@ private:
};
/**
* A special kind of KMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
*
* The main widget should be a KDockWidget where other KDockWidget can be docked to
* the left, right, top, bottom or to the middle.
@@ -1311,7 +1311,7 @@ private:
*
* @author Max Judin (documentation: Falk Brettschneider).
*/
-class TDEUI_EXPORT KDockMainWindow : public KMainWindow
+class TDEUI_EXPORT KDockMainWindow : public TDEMainWindow
{
Q_OBJECT
@@ -1390,20 +1390,20 @@ public:
#ifndef NO_KDE2
/**
* It writes the current dock state in the given section of KConfig.
*
* @param c KDE class for saving configurations
* @param group name of section to write to
*/
- void writeDockConfig( KConfig* c = 0L, TQString group = TQString::null );
+ void writeDockConfig( TDEConfig* c = 0L, TQString group = TQString::null );
/**
* It reads the current dock state from the given section of KConfig.
*
* @param c KDE class for saving configurations
* @param group name of section to read from
*/
- void readDockConfig ( KConfig* c = 0L, TQString group = TQString::null );
+ void readDockConfig ( TDEConfig* c = 0L, TQString group = TQString::null );
#endif
/**
@@ -1509,8 +1509,8 @@ public:
void readDockConfig(TQDomElement &base);
#ifndef NO_KDE2
- void writeDockConfig( KConfig* c = 0L, TQString group = TQString::null );
- void readDockConfig ( KConfig* c = 0L, TQString group = TQString::null );
+ void writeDockConfig( TDEConfig* c = 0L, TQString group = TQString::null );
+ void readDockConfig ( TDEConfig* c = 0L, TQString group = TQString::null );
#endif
@@ -906,7 +906,7 @@ private:
*
* An important feature is the ability to read or save the current state of all things concerning to
- * dockwidgets to KConfig .
+ * dockwidgets to TDEConfig .
*
* The dockmanager is also often used when a certain dockwidget or a child of such dockwidget must be found.
@@ -954,9 +954,9 @@ public:
*
* @param c the KDE configuration saver
- * @param group the name of the section in KConfig
+ * @param group the name of the section in TDEConfig
*/
@@ -972,9 +972,9 @@ public:
*
* @param c the KDE configuration saver
- * @param group the name of the section in KConfig
+ * @param group the name of the section in TDEConfig
*/
@@ -1269,7 +1269,7 @@ private:
};
/**
- * A special kind of KMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
+ * A special kind of TDEMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
*
* The main widget should be a KDockWidget where other KDockWidget can be docked to
@@ -1390,20 +1390,20 @@ public:
#ifndef NO_KDE2
/**
- * It writes the current dock state in the given section of KConfig.
+ * It writes the current dock state in the given section of TDEConfig.
*
* @param c KDE class for saving configurations
@@ -1390,20 +1390,20 @@ public:
/**
- * It reads the current dock state from the given section of KConfig.
+ * It reads the current dock state from the given section of TDEConfig.
*
* @param c KDE class for saving configurations